
.. include:: README.rst

.. toctree::
    :caption: Getting started
    :maxdepth: 2
    :hidden:

    quickstart

.. toctree::
    :caption: Data structures
    :maxdepth: 2
    :hidden:

    data/image
    data/subject
    data/dataset
    data/patch_based

.. toctree::
    :caption: Transforms
    :maxdepth: 2
    :hidden:

    transforms/transforms

.. toctree::
    :caption: Medical image datasets
    :maxdepth: 2
    :hidden:

    datasets

.. toctree::
    :caption: Interfaces
    :maxdepth: 2
    :hidden:

    interfaces/index
    interfaces/cli
    interfaces/slicer


See also
********

PyTorch implementations of 2D and 3D network architectures:

* `HighResNet <https://www.github.com/fepegar/highresnet>`_
* `U-Net <https://www.github.com/fepegar/unet>`_
